You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by ak...@apache.org on 2007/10/15 03:05:26 UTC

svn commit: r584649 - in /directory/apacheds/branches/bigbang: server-jndi/src/main/java/org/apache/directory/server/configuration/ server-jndi/src/main/java/org/apache/directory/server/jndi/ server-sar/src/main/resources/META-INF/ server-unit/src/main...

Author: akarasulu
Date: Sun Oct 14 18:05:23 2007
New Revision: 584649

URL: http://svn.apache.org/viewvc?rev=584649&view=rev
Log:
removing ServerContextFactory which is now not needed

Removed:
    directory/apacheds/branches/bigbang/server-jndi/src/main/java/org/apache/directory/server/jndi/ServerContextFactory.java
Modified:
    directory/apacheds/branches/bigbang/server-jndi/src/main/java/org/apache/directory/server/configuration/ApacheDS.java
    directory/apacheds/branches/bigbang/server-sar/src/main/resources/META-INF/jboss-service.xml
    directory/apacheds/branches/bigbang/server-unit/src/main/java/org/apache/directory/server/unit/AbstractServerFastTest.java
    directory/apacheds/branches/bigbang/server-unit/src/main/java/org/apache/directory/server/unit/AbstractServerTest.java
    directory/apacheds/branches/bigbang/server-xml/src/test/java/org/apache/directory/server/SpringServerTest.java

Modified: directory/apacheds/branches/bigbang/server-jndi/src/main/java/org/apache/directory/server/configuration/ApacheDS.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/bigbang/server-jndi/src/main/java/org/apache/directory/server/configuration/ApacheDS.java?rev=584649&r1=584648&r2=584649&view=diff
==============================================================================
--- directory/apacheds/branches/bigbang/server-sar/src/main/resources/META-INF/jboss-service.xml (original)
+++ directory/apacheds/branches/bigbang/server-sar/src/main/resources/META-INF/jboss-service.xml Sun Oct 14 18:05:23 2007
@@ -6,9 +6,6 @@
 		name="apacheds.system:service=Directory">
 
 		<attribute name="EmbeddedServerEnabled">true</attribute>
-		<attribute name="ContextFactory">
-			org.apache.directory.server.jndi.ServerContextFactory
-		</attribute>
 		<attribute name="ContextProviderURL">
 			uid=admin,ou=system
 		</attribute>

Modified: directory/apacheds/branches/bigbang/server-unit/src/main/java/org/apache/directory/server/unit/AbstractServerFastTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/bigbang/server-unit/src/main/java/org/apache/directory/server/unit/AbstractServerFastTest.java?rev=584649&r1=584648&r2=584649&view=diff
==============================================================================
--- directory/apacheds/branches/bigbang/server-unit/src/main/java/org/apache/directory/server/unit/AbstractServerFastTest.java (original)
+++ directory/apacheds/branches/bigbang/server-unit/src/main/java/org/apache/directory/server/unit/AbstractServerFastTest.java Sun Oct 14 18:05:23 2007
@@ -22,9 +22,9 @@
 
 import junit.framework.AssertionFailedError;
 import org.apache.commons.io.FileUtils;
-import org.apache.directory.server.jndi.ServerContextFactory;
-import org.apache.directory.server.core.DirectoryService;
 import org.apache.directory.server.core.DefaultDirectoryService;
+import org.apache.directory.server.core.DirectoryService;
+import org.apache.directory.server.core.jndi.CoreContextFactory;
 import org.apache.directory.server.ldap.LdapServer;
 import org.apache.directory.server.protocol.shared.SocketAcceptor;
 import org.apache.directory.shared.ldap.exception.LdapConfigurationException;
@@ -38,7 +38,10 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import javax.naming.*;
+import javax.naming.Context;
+import javax.naming.NameAlreadyBoundException;
+import javax.naming.NamingEnumeration;
+import javax.naming.NamingException;
 import javax.naming.directory.Attribute;
 import javax.naming.directory.Attributes;
 import javax.naming.ldap.InitialLdapContext;
@@ -220,7 +223,7 @@
         env.put( Context.SECURITY_PRINCIPAL, "uid=admin,ou=system" );
         env.put( Context.SECURITY_CREDENTIALS, "secret" );
         env.put( Context.SECURITY_AUTHENTICATION, "simple" );
-        env.put( Context.INITIAL_CONTEXT_FACTORY, ServerContextFactory.class.getName() );
+        env.put( Context.INITIAL_CONTEXT_FACTORY, CoreContextFactory.class.getName() );
 
         setContexts( env );
     }

Modified: directory/apacheds/branches/bigbang/server-unit/src/main/java/org/apache/directory/server/unit/AbstractServerTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/bigbang/server-unit/src/main/java/org/apache/directory/server/unit/AbstractServerTest.java?rev=584649&r1=584648&r2=584649&view=diff
==============================================================================
--- directory/apacheds/branches/bigbang/server-unit/src/main/java/org/apache/directory/server/unit/AbstractServerTest.java (original)
+++ directory/apacheds/branches/bigbang/server-unit/src/main/java/org/apache/directory/server/unit/AbstractServerTest.java Sun Oct 14 18:05:23 2007
@@ -20,29 +20,12 @@
 package org.apache.directory.server.unit;
 
 
-import java.io.File;
-import java.io.IOException;
-import java.io.InputStream;
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.Hashtable;
-import java.util.Iterator;
-import java.util.List;
-
-import javax.naming.Context;
-import javax.naming.NamingEnumeration;
-import javax.naming.NamingException;
-import javax.naming.directory.Attribute;
-import javax.naming.directory.Attributes;
-import javax.naming.ldap.InitialLdapContext;
-import javax.naming.ldap.LdapContext;
-
 import junit.framework.AssertionFailedError;
 import junit.framework.TestCase;
 import org.apache.commons.io.FileUtils;
 import org.apache.directory.server.core.DefaultDirectoryService;
 import org.apache.directory.server.core.DirectoryService;
-import org.apache.directory.server.jndi.ServerContextFactory;
+import org.apache.directory.server.core.jndi.CoreContextFactory;
 import org.apache.directory.server.ldap.LdapServer;
 import org.apache.directory.server.protocol.shared.SocketAcceptor;
 import org.apache.directory.shared.ldap.exception.LdapConfigurationException;
@@ -53,6 +36,18 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import javax.naming.Context;
+import javax.naming.NamingEnumeration;
+import javax.naming.NamingException;
+import javax.naming.directory.Attribute;
+import javax.naming.directory.Attributes;
+import javax.naming.ldap.InitialLdapContext;
+import javax.naming.ldap.LdapContext;
+import java.io.File;
+import java.io.IOException;
+import java.io.InputStream;
+import java.util.*;
+
 
 /**
  * A simple testcase for testing JNDI provider functionality.
@@ -289,7 +284,7 @@
         env.put( Context.SECURITY_PRINCIPAL, user );
         env.put( Context.SECURITY_CREDENTIALS, passwd );
         env.put( Context.SECURITY_AUTHENTICATION, "simple" );
-        env.put( Context.INITIAL_CONTEXT_FACTORY, ServerContextFactory.class.getName() );
+        env.put( Context.INITIAL_CONTEXT_FACTORY, CoreContextFactory.class.getName() );
         setContexts( env );
     }
 

Modified: directory/apacheds/branches/bigbang/server-xml/src/test/java/org/apache/directory/server/SpringServerTest.java
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/bigbang/server-xml/src/test/java/org/apache/directory/server/SpringServerTest.java?rev=584649&r1=584648&r2=584649&view=diff
==============================================================================
--- directory/apacheds/branches/bigbang/server-xml/src/test/java/org/apache/directory/server/SpringServerTest.java (original)
+++ directory/apacheds/branches/bigbang/server-xml/src/test/java/org/apache/directory/server/SpringServerTest.java Sun Oct 14 18:05:23 2007
@@ -19,7 +19,6 @@
 package org.apache.directory.server;
 
 import org.apache.directory.server.configuration.ApacheDS;
-import org.apache.directory.server.jndi.ServerContextFactory;
 import org.apache.xbean.spring.context.FileSystemXmlApplicationContext;
 import org.junit.Test;
 import org.springframework.context.ApplicationContext;
--- directory/apacheds/branches/bigbang/server-jndi/src/main/java/org/apache/directory/server/configuration/ApacheDS.java (original)
+++ directory/apacheds/branches/bigbang/server-jndi/src/main/java/org/apache/directory/server/configuration/ApacheDS.java Sun Oct 14 18:05:23 2007
@@ -20,24 +20,11 @@
 package org.apache.directory.server.configuration;
 
 
-import java.io.File;
-import java.io.FileFilter;
-import java.io.IOException;
-import java.util.ArrayList;
-import java.util.Hashtable;
-import java.util.List;
-
-import javax.naming.Context;
-import javax.naming.NamingException;
-import javax.naming.directory.Attributes;
-import javax.naming.directory.DirContext;
-import javax.naming.directory.InitialDirContext;
-
 import org.apache.commons.lang.StringUtils;
 import org.apache.directory.server.constants.ApacheSchemaConstants;
 import org.apache.directory.server.core.DefaultDirectoryService;
 import org.apache.directory.server.core.DirectoryService;
-import org.apache.directory.server.jndi.ServerContextFactory;
+import org.apache.directory.server.core.jndi.CoreContextFactory;
 import org.apache.directory.server.ldap.LdapServer;
 import org.apache.directory.server.protocol.shared.store.LdifFileLoader;
 import org.apache.directory.server.protocol.shared.store.LdifLoadFilter;
@@ -49,6 +36,18 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import javax.naming.Context;
+import javax.naming.NamingException;
+import javax.naming.directory.Attributes;
+import javax.naming.directory.DirContext;
+import javax.naming.directory.InitialDirContext;
+import java.io.File;
+import java.io.FileFilter;
+import java.io.IOException;
+import java.util.ArrayList;
+import java.util.Hashtable;
+import java.util.List;
+
 
 /**
  * Apache Directory Server top level.
@@ -314,7 +313,7 @@
 */
 
     // ----------------------------------------------------------------------
     // From ServerContextFactory: presently in intermediate step but these
     // methods will be moved to the appropriate protocol service eventually.
     // This is here simply to start to remove the JNDI dependency then further
     // refactoring will be needed to place these where they belong.
@@ -418,9 +417,8 @@
         //noinspection unchecked
         Hashtable<String, Object> env = ( Hashtable<String, Object> ) environment.clone();
         env.put( Context.PROVIDER_URL, "" );
-//        env.put( ApacheDS.JNDI_KEY, this );
         env.put( DirectoryService.JNDI_KEY, directoryService );
-        env.put( Context.INITIAL_CONTEXT_FACTORY, ServerContextFactory.class.getName() );
+        env.put( Context.INITIAL_CONTEXT_FACTORY, CoreContextFactory.class.getName() );
         DirContext root = new InitialDirContext( env );
 
         // make sure the configuration area for loaded ldif files is present
@@ -314,7 +313,7 @@
 
     // ----------------------------------------------------------------------
-    // From ServerContextFactory: presently in intermediate step but these
+    // From CoreContextFactory: presently in intermediate step but these
     // methods will be moved to the appropriate protocol service eventually.
     // This is here simply to start to remove the JNDI dependency then further

Modified: directory/apacheds/branches/bigbang/server-sar/src/main/resources/META-INF/jboss-service.xml
URL: http://svn.apache.org/viewvc/directory/apacheds/branches/bigbang/server-sar/src/main/resources/META-INF/jboss-service.xml?rev=584649&r1=584648&r2=584649&view=diff
==============================================================================